<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Sync directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	M. Carroll
Name:
	ce_field_select_render.cfm
Summary:
	Select tool for the custom element fields connected to the CE Form Select custom field.
	CFT to select the custom element fields based on the property field for 
		the custom element.
	Stores the CE Field ID.
ADF App:
	PT Sync
Version:
	1.0
History:
	2011-08-21 - MFC - Created
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	//--Field Security--
	readOnly = application.ptSync.forms.isFieldReadOnly(xparams);
	
	// Validate if the property field has been defined
	if ( NOT StructKeyExists(xparams, "sourceCEfldID") OR LEN(xparams.sourceCEfldID) LTE 0 )
		xparams.sourceCEfldID = "";
		
	// Load JQuery
	application.ptSync.scripts.loadJQuery();
	application.ptSync.scripts.loadJQuerySelectboxes();
</cfscript>
<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.msg="Please select a value for the #xparams.label# field.";
		#fqFieldName#.validator = "validate_#fqFieldName#()";

		//If the field is required
		if ( '#xparams.req#' == 'Yes' ){
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}

		//Validation function
		function validate_#fqFieldName#(){
			//if (jQuery("input[name=#fqFieldName#]").val() != ''){
			if (jQuery("select###fqFieldName# :selected").val() != ''){
				return true;
			}else{
				return false;
			}
		}
		
		jQuery(function() {
			// Add an onchange event for the source CE field
			jQuery("select###xparams.sourceCEfldID#").change(function() {
				//alert('Handler for .change() called.');
				// Call the update select field function
				#fqFieldName#_updateSelectField();
			});
			
			// Get the value from the source CE field
			var sourceCE = jQuery.trim(jQuery("select###xparams.sourceCEfldID# :selected").val());
			// Check if the Source CE field is set from an edit/update
			if ( sourceCE != "" ){
				//#fqFieldName#_updateSelectField();
				#fqFieldName#_handleFormIDPost(sourceCE);
				
				// Load the current value into a JS variable
				jsCurrentValue = "#currentValue#"
				if ( jsCurrentValue != "" ){
					// Load in the current selected values
					jQuery("###fqFieldName#").selectOptions(jsCurrentValue);
				}
			}
		});
		
		function #fqFieldName#_updateSelectField(){
			// Get the value from the source CE field
			var sourceCE = jQuery.trim(jQuery("select###xparams.sourceCEfldID# :selected").val());
			//alert(sourceCE);
			
			// Get the CE Form ID for the custom element name
			#fqFieldName#_handleFormIDPost(sourceCE);
		}
		
		// Get the fields for the CE Form ID
		function #fqFieldName#_handleFormIDPost(results){
			//alert(results);
			if(results != 0){
				// Get the fields based on the tabs in the custom element
				//	Call the "handleTabsFromFormIDPost" function to populate the select field.
				jQuery.ajax({
				  type: 'POST',
				  url: "#application.ADF.ajaxProxy#",
				  data: { bean: "ceData_1_1",
						  method: "getTabsFromFormID",
						  returnformat: "json",
						  formID: results,
						  recurse: true},
				  success: #fqFieldName#_handleTabsFromFormIDPost,
				  async: false
				},"json");
			}
		}
		
		// Handle getting the tab data and populate the select box
		function #fqFieldName#_handleTabsFromFormIDPost(results){
			var fields = new Object();
			if(typeof results === "string"){
				results = jQuery.parseJSON(results);
			}
			var fieldInfo = results;
			if(!jQuery.isArray(fieldInfo)){
				var fieldInfoTemp = Array();
				fieldInfoTemp[1] = fieldInfo;
				fieldInfo = fieldInfoTemp;
			}
			
			// Loop over each tab to create an object keyed on the field name with a value of label.
			jQuery(fieldInfo).each(function(fieldIndex,tab){
				jQuery(tab['FIELDS']).each(function(index,field){
					//fields[field.DEFAULTVALUES.FIELDNAME] = field.DEFAULTVALUES.LABEL;
					fields[field.FIELDID] = field.DEFAULTVALUES.LABEL;
				});
			});
	
			//Remove options
			jQuery("###fqFieldName#").removeOption(/./);
			
			//Add new options
			jQuery("###fqFieldName#").addOption(fields);
			
			//Deselect everything
			jQuery("###fqFieldName#").selectOptions(jQuery("###fqFieldName#").selectedOptions(),true);
		}
		
	</script>
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->
	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<select name="#fqFieldName#" id="#fqFieldName#">
			</select>
		</cfoutput>
	</cfsavecontent>
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes)#
</cfoutput>