<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Sync directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	M. Carroll
Name:
	dest_ce_validate_render.cfm
Summary:
	CFT to validate the source CE to the destination site to verify the CE 
		with the same name exists.
	Stores the CE Form ID for the destination site.
ADF App:
	PT Sync
Version:
	1.0
History:
	2011-04-08 - MFC - Created
	2011-10-11 - MFC - Updated to run the validate when the form loads. This will update
							the field if the configuration has changed.
					   Updated the jsMultiServerEnabled variable to lowercase and changed
					   		the IF condition to string and lowercase.
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	//--Field Security--
	readOnly = application.ADF.forms.isFieldReadOnly(xparams);
	
	// Validate if the property field has been defined
	if ( NOT StructKeyExists(xparams, "sourceCEfldID") OR LEN(xparams.sourceCEfldID) LTE 0 )
		xparams.sourceCEfldID = "";
		
	// Load JQuery
	application.ptSync.scripts.loadJQuery();
</cfscript>
<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.msg="Please select a value for the #xparams.label# field.";
		#fqFieldName#.validator = "validate_#fqFieldName#()";

		//If the field is required
		if ( '#xparams.req#' == 'Yes' ){
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}

		//Validation function
		function validate_#fqFieldName#(){
			if (jQuery("input[name=#fqFieldName#]").val() != ''){
				return true;
			}else{
				return false;
			}
		}
		
		// Set the config multi server variable into JS
		//	2011-10-11 - MFC - Set the variable to lowercase.
		jsMultiServerEnabled = "#LCASE(application.ptSync.appConfig.multiserver)#";
		
		jQuery(function() {
			// Add an onchange event for the source CE field
			jQuery("select###xparams.sourceCEfldID#").change(function() {
				//alert('Handler for .change() called.');
				// Call the validation function
				#fqFieldName#_validate();
			});
			
			//alert('[#currentValue#]');
			// Check if the field has a value
			if ( '#currentValue#' != '' ){
				/*	2011-10-11 - MFC
				*	Call the validation function, set the value based
				*		 on if the site configuration has changed.
				*/
				#fqFieldName#_validate();
			}
			else {
				// Update the message
				#fqFieldName#_setCEFormID(0);
			}
		});
		
		function #fqFieldName#_validate(){
			
			// Update the message
			jQuery('###fqFieldName#-display').html("Validating...");
			
			// Get the value from the source CE field
			var sourceCE = jQuery.trim(jQuery("select###xparams.sourceCEfldID# :selected").text());
			//alert(sourceCE);
			
			// Check if running the MULTI Server
			//	2011-10-11 - MFC - Updated the IF condition to lowercase and string.
			if ( jsMultiServerEnabled == "true" ){
				// Call the internal function to make an CFHTTP call to the server
				//	Prevents the browser thinking this is a cross-site attack			
				jQuery.ajax({
					type: 'GET',
					url: "#application.ADF.ajaxProxy#",
					data:{
						bean: 'syncController',
						method: 'getMultiServerServerFormID',
						CEName: sourceCE
					},
					success: function(formData){
						// Pass return to function to set the form field text
						#fqFieldName#_setCEFormID(formData);
					}
				});	
			} 
			else {
				// Make the straight call to the same server
				jQuery.ajax({
					type: 'GET',
					url: "#application.ADF.ajaxProxy#",
					data:{
						bean: 'ptSync_ceData_1_1',
						method: 'getFormIDByCEName',
						CEName: sourceCE,
						qryDataSource: '#application.ptSync.cache.siteData.dest.datasourceName#'
					},
					success: function(formData){
						// Pass return to function to set the form field text
						#fqFieldName#_setCEFormID(formData);
					}
				});	
			}
		}
		
		function #fqFieldName#_setCEFormID(formID){
			//alert(formData);
			if ( formID > 0 ) {
				// Set the data into the field
				jQuery('###fqFieldName#').val(formID);
				// Update the message
				jQuery('###fqFieldName#-display').html("Custom element validated on the destination server.");
			}
			else {
				// Clear the data into the field
				jQuery('###fqFieldName#').val(0);
				// Update the message
				jQuery('###fqFieldName#-display').html("Custom element not validated.");				
			} 
		}
		
	</script>
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->
	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<font face="Verdana,Arial" color="##000000" size="2">
				<div id="#fqFieldName#-display">
					Validating...
				</div>
			</font>
			<input type="hidden" name="#fqFieldName#" id="#fqFieldName#" value="#currentValue#">
		</cfoutput>
	</cfsavecontent>
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes)#
</cfoutput>